Cubic constructor

Cubic(
  1. double anchor0X,
  2. double anchor0Y,
  3. double control0X,
  4. double control0Y,
  5. double control1X,
  6. double control1Y,
  7. double anchor1X,
  8. double anchor1Y,
)

Creates a Cubic that holds the anchor and control point data for a single Bézier curve, with anchor points (anchor0X, anchor0Y) and (anchor1X, anchor1Y) at either end and control points (control0X, control0Y) and (control1X, control1Y) determining the slope of the curve between the anchor points.

Implementation

Cubic(
  double anchor0X,
  double anchor0Y,
  double control0X,
  double control0Y,
  double control1X,
  double control1Y,
  double anchor1X,
  double anchor1Y,
) : this._raw([
        anchor0X,
        anchor0Y,
        control0X,
        control0Y,
        control1X,
        control1Y,
        anchor1X,
        anchor1Y,
      ]);