shape property
The shape this border represents.
This value could be null if border is the result of lerp.
Implementation
final RoundedPolygon? shape;
The shape this border represents.
This value could be null if border is the result of lerp.
final RoundedPolygon? shape;