RoundedPolygonToPathExtension extension

on

Methods

toPath({int startAngle = 0, bool repeatPath = false, bool closePath = true, Path? path}) Path

Available on RoundedPolygon, provided by the RoundedPolygonToPathExtension extension

Returns a Path representation for a RoundedPolygon shape. Note that there is some rounding happening (to the nearest thousandth), to work around rendering artifacts introduced by some points being just slightly off from each other (far less than a pixel). This also allows for a more optimal path, as redundant curves (usually a single point) can be detected and not added to the resulting path.